@@ -41,19 +41,22 @@ jqr_feed <- function(jqr_program, json, unlist = TRUE, finalize = FALSE){
   return(out)
 }
 
+#' @export
 jqr <- function(x, ...) {
   UseMethod("jqr", x)
 }
 
-jqr.default <- function(json, query, flags){
-  #json <- paste(json, collapse = "\n")
+#' @export
+jqr.default <- function(x, query, flags, ...){
   stopifnot(is.character(query))
   stopifnot(is.numeric(flags))
   program <- jqr_new(query, flags = flags)
-  jqr_feed(program, json = json, unlist = TRUE, finalize = TRUE)
+  jqr_feed(program, json = x, unlist = TRUE, finalize = TRUE)
 }
 
-jqr.connection <- function(con, query, flags, out = NULL){
+#' @export
+jqr.connection <- function(x, query, flags, out = NULL, ...){
+  con <- x
   val <- invisible()
   stopifnot(inherits(con, 'connection'))
   if(is.character(out))
